@@ -12,6 +12,8 @@
   data=eval(out$data))
   out$terms <- attr(out$model, "terms")
   attr(out$terms,"intercept") <- 0
+  if (is.null(zcall$seed)) out$seed <- NA
+    else out$seed <- zcall$seed
   class(out) <- "MCMCZelig"
 
  out
@@ -28,6 +30,9 @@ zelig3MCMClogit <- zelig3MCMCoprobit <- zelig3MCMCpoisson <-
   out$model <- model.frame(formula=eval(out$formula),
   data=eval(out$data))
   out$terms <- attr(out$model, "terms")
+  if (is.null(zcall$seed)) out$seed <- NA
+    else out$seed <- zcall$seed
+
   class(out) <- "MCMCZelig"
 
  out
@@ -53,6 +58,9 @@ zelig3MCMCprobit <- function(res, fcall=NULL, zcall=NULL) {
 
   out$model <- model.frame(formula=eval(out$formula),data=eval(out$data))
   out$terms <- attr(out$model, "terms")
+  if (is.null(zcall$seed)) out$seed <- NA
+    else out$seed <- zcall$seed
+
   class(out) <- "MCMCZelig"
 
  out
@@ -75,6 +83,9 @@ zelig3MCMCprobit <- function(res, fcall=NULL, zcall=NULL) {
   out$model <- model.frame(formula=eval(out$formula),
   data=eval(out$data))
   out$terms <- attr(out$model, "terms")
+  if (is.null(zcall$seed)) out$seed <- NA
+    else out$seed <- zcall$seed
+
   class(out) <- "MCMCZelig"
 
  out
@@ -91,6 +102,29 @@ zelig3MCMCprobit <- function(res, fcall=NULL, zcall=NULL) {
   data=eval(out$data))
   out$terms <- attr(out$model, "terms")
   attr(out$terms,"intercept") <- 0
+  if (is.null(zcall$seed)) out$seed <- NA
+    else out$seed <- zcall$seed
+
+  class(out) <- "MCMCZelig"
+
+ out
+}
+
+
+  zelig3MCMCirt1d <- zelig3MCMCirtKd <- function(res, fcall=NULL, zcall=NULL) {
+
+  out <- list()
+  out$coefficients <- res
+  out$formula <- zcall$formula
+  out$data <- zcall$data
+  
+  out$model <- model.frame(formula=eval(out$formula),
+  data=eval(out$data))
+  out$terms <- attr(out$model, "terms")
+  attr(out$terms,"intercept") <- 0
+  if (is.null(zcall$seed)) out$seed <- NA
+    else out$seed <- zcall$seed
+
   class(out) <- "MCMCZelig"
 
  out
